emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/language/ethiopic.el,v


From: Miles Bader
Subject: [Emacs-diffs] Changes to emacs/lisp/language/ethiopic.el,v
Date: Fri, 01 Feb 2008 16:02:35 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Miles Bader <miles>     08/02/01 16:01:31

Index: lisp/language/ethiopic.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/language/ethiopic.el,v
retrieving revision 1.27
retrieving revision 1.28
diff -u -b -r1.27 -r1.28
--- lisp/language/ethiopic.el   8 Jan 2008 20:45:58 -0000       1.27
+++ lisp/language/ethiopic.el   1 Feb 2008 16:01:04 -0000       1.28
@@ -1,4 +1,4 @@
 ;;; ethiopic.el --- support for Ethiopic -*- coding: iso-2022-7bit; -*-
 
 ;; Copyright (C) 1997, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
 ;;   Free Software Foundation, Inc.
@@ -44,10 +44,10 @@
      (r1 *= 94)
      (r2 += r1)
      (if (r2 < 256)
-        (r1 = ?\x12)
+        (r1 = #x12)
        (if (r2 < 448)
-          ((r1 = ?\x13) (r2 -= 256))
-        ((r1 = ?\xfd) (r2 -= 208))
+          ((r1 = #x13) (r2 -= 256))
+        ((r1 = #xfd) (r2 -= 208))
         ))))
   "CCL program to encode an Ethiopic code to code point of Ethiopic font.")
 
@@ -58,30 +58,33 @@
  "Ethiopic" '((setup-function . setup-ethiopic-environment-internal)
              (exit-function . exit-ethiopic-environment)
              (charset ethiopic)
-             (coding-system iso-2022-7bit)
-             (coding-priority iso-2022-7bit)
+             (coding-system utf-8-emacs)
+             (coding-priority utf-8-emacs)
              (input-method . "ethiopic")
              (features ethio-util)
-             (sample-text . "$(3$Q#U!.(B")
+             (sample-text . "ፊደል")
              (documentation .
-"This language envrironment provides these function key bindings
-    \(old bindings are shown in parentheses):
-    [f3]   ethio-fidel-to-sera-buffer         (f5)
-    [S-f3] ethio-fidel-to-sera-region         (f5)
-    [C-f3] ethio-fidel-to-sera-mail-or-marker (f5)
-
-    [f4]   ethio-sera-to-fidel-buffer         (unchanged)
-    [S-f4] ethio-sera-to-fidel-region         (unchanged)
-    [C-f4] ethio-sera-to-fidel-mail-or-marker (unchanged)
-
-    [S-f5] ethio-toggle-punctuation           (f3)
-    [S-f6] ethio-modify-vowel                 (f6)
-    [S-f7] ethio-replace-space                (f7)
-    [S-f8] ethio-input-special-character      (f8)
-    [S-f9] ethio-replace-space                (unchanged)
-    [C-f9] ethio-toggle-space                 (f2)"
+"This language envrironment provides these function key bindings:
+    [f3]   ethio-fidel-to-sera-buffer
+    [S-f3] ethio-fidel-to-sera-region
+    [C-f3] ethio-fidel-to-sera-marker
+
+    [f4]   ethio-sera-to-fidel-buffer
+    [S-f4] ethio-sera-to-fidel-region
+    [C-f4] ethio-sera-to-fidel-marker
+
+    [S-f5] ethio-toggle-punctuation
+    [S-f6] ethio-modify-vowel
+    [S-f7] ethio-replace-space
+
+    [S-f9] ethio-replace-space
+    [C-f9] ethio-toggle-space"
 )))
 
+;; For automatic composition
+(aset composition-function-table ?ö ‡Š 'ethio-composition-function)
+(aset composition-function-table ?፟ 'ethio-composition-function)
+
 (provide 'ethiopic)
 
 ;;; arch-tag: e81329d9-1286-43ba-92fd-54ce5c7b213c
@@ -1,4 +1,4 @@
-;;; ethiopic.el --- support for Ethiopic -*- coding: iso-2022-7bit; -*-
+;;; ethiopic.el --- support for Ethiopic       -*- coding: utf-8-emacs; -*-
 
 ;; Copyright (C) 1997, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008




reply via email to

[Prev in Thread] Current Thread [Next in Thread]